==> kakao_flutter_sdk_navi-1.3.0.tar.gz: README.md <==
# kakao_flutter_sdk

This document introduces how to use the Kakao SDK for Flutter (Flutter SDK). The Flutter SDK supports Android and iOS platforms as of now, and will support web platform in the near future.

## Requirements

Here are what you need to use the Flutter SDK:

- Dart 2.14.0 or higher
- Flutter 2.0.0 or higher
- Android Studio 3.6.1 or higher
- Target Android API level 19 or higher (Android 4.4 (Kitkat) or higher)
- Xcode 11.0 or higher
- iOS 11.0 or higher
- iOS Deployment Target 11.0 or higher
- [Web browser support](https://developers.kakao.com/docs/latest/getting-started/sdk-flutter#supported-browser)

## How to develop

To integrate the Kakao APIs with the Flutter SDK, read the following documentation:

- [Getting started](https://developers.kakao.com/docs/latest/getting-started/sdk-flutter)
- [Kakao Login](https://developers.kakao.com/docs/latest/kakaologin/flutter)
- [Kakao Talk Social](https://developers.kakao.com/docs/latest/kakaotalk-social/flutter)
- [Kakao Talk Sharing](https://developers.kakao.com/docs/latest/message/flutter-link)
- [Kakao Talk Messaging](https://developers.kakao.com/docs/latest/message/flutter)
- [Kakao Story](https://developers.kakao.com/docs/latest/kakaostory/flutter)
- [Kakao Talk Channel](https://developers.kakao.com/docs/latest/kakaotalk-channel/flutter)
- [Kakao Sync](https://developers.kakao.com/docs/latest/kakaosync/terms#flutter)
- [Kakao Navi](https://developers.kakao.com/docs/latest/kakaonavi/flutter)

## How to Contribute

If you want to contribute to this repository, read the followings:

- [Submitting Pull Requests](https://github.com/kakao/kakao_flutter_sdk/wiki/Submitting-Pull-Requests)
- [Development Guide](https://github.com/kakao/kakao_flutter_sdk/wiki/Development-Guide)

## License

This software is licensed under the [Apache 2 license](packages/kakao_flutter_sdk/LICENSE), quoted below.

Copyright 2019 Kakao Corp. <https://www.kakaocorp.com>

Licensed under the Apache License, Version 2.0 (the "License"); you may not
use this project except in compliance with the License. You may obtain a copy
of the License at http://www.apache.org/licenses/LICENSE-2.0.

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
License for the specific language governing permissions and limitations under
the License.

==> kakao_flutter_sdk_navi-1.4.2.tar.gz: README.md <==
# kakao_flutter_sdk

This document introduces how to use the Kakao SDK for Flutter (Flutter SDK). The Flutter SDK supports Android and iOS platforms as of now, and will support web platform in the near future.

## Requirements

Here are what you need to use the Flutter SDK:

- Dart 2.14.0 or higher
- Flutter 2.0.0 or higher
- Android Studio 3.6.1 or higher
- Target Android API level 21 or higher (Android 5.0 (Lollipop) or higher)
- Xcode 11.0 or higher
- iOS 11.0 or higher
- iOS Deployment Target 11.0 or higher
- [Web browser support](https://developers.kakao.com/docs/latest/getting-started/sdk-flutter#supported-browser)

## How to develop

To integrate the Kakao APIs with the Flutter SDK, read the following documentation:

- [Getting started](https://developers.kakao.com/docs/latest/getting-started/sdk-flutter)
- [Kakao Login](https://developers.kakao.com/docs/latest/kakaologin/flutter)
- [Kakao Talk Social](https://developers.kakao.com/docs/latest/kakaotalk-social/flutter)
- [Kakao Talk Sharing](https://developers.kakao.com/docs/latest/message/flutter-link)
- [Kakao Talk Messaging](https://developers.kakao.com/docs/latest/message/flutter)
- [Kakao Story](https://developers.kakao.com/docs/latest/kakaostory/flutter)
- [Kakao Talk Channel](https://developers.kakao.com/docs/latest/kakaotalk-channel/flutter)
- [Kakao Sync](https://developers.kakao.com/docs/latest/kakaosync/terms#flutter)
- [Kakao Navi](https://developers.kakao.com/docs/latest/kakaonavi/flutter)

## How to Contribute

If you want to contribute to this repository, read the followings:

- [Submitting Pull Requests](https://github.com/kakao/kakao_flutter_sdk/wiki/Submitting-Pull-Requests)
- [Development Guide](https://github.com/kakao/kakao_flutter_sdk/wiki/Development-Guide)

## License

This software is licensed under the [Apache 2 license](packages/kakao_flutter_sdk/LICENSE), quoted below.

Copyright 2019 Kakao Corp. <https://www.kakaocorp.com>

Licensed under the Apache License, Version 2.0 (the "License"); you may not
use this project except in compliance with the License. You may obtain a copy
of the License at http://www.apache.org/licenses/LICENSE-2.0.

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
License for the specific language governing permissions and limitations under
the License.
